ui

package
v0.0.0-...-2607e71 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 3, 2020 License: GPL-3.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	// App is the app
	App *tview.Application

	// Pages represents the apps pages
	Pages *tview.Pages
)

Functions

func Center

func Center(width, height int, p tview.Primitive) tview.Primitive

Center returns a new primitive which shows the provided primitive in its center, given the provided primitive's size.

func LogoArt

func LogoArt(text, font string) (width, height int, logoBox *tview.TextView)

LogoArt returns a new primitive, and it's size, which contains an Ascii art of the input text

Types

This section is empty.

Jump to